@@ -28,7 +28,8 @@
 #include <libgnomemm/main.h>
 #include <libgnomeuimm/about.h>
 #include <gtkmm/messagedialog.h>
-#include <gnome.h> //For stock icons.
+#include <gtkmm/stock.h>
+//#include <gnome.h> //For stock icons.
 #include <cstdio>
 #include <algorithm> //For std::reverse().
 
@@ -63,7 +64,6 @@ void AppSet::close_all()
 Hello_App::Hello_App(const Glib::ustring& message)
   : Gnome::UI::App("GnomeHello", "Gnome Hello"),
           label_(_("Hello, World!")),
-           status_(false, true, GNOME_PREFERENCES_NEVER),
            about_(0)
 {
   init();
@@ -72,7 +72,6 @@ Hello_App::Hello_App(const Glib::ustring& message)
 
 Hello_App::Hello_App(const Glib::ustring& message,  const std::vector<Glib::ustring> &greet)
 : Gnome::UI::App("GnomeHello", "Gnome Hello"),
-         status_(false, true, GNOME_PREFERENCES_NEVER),
          about_(0)
 {
 
@@ -89,7 +88,7 @@ Hello_App::Hello_App(const Glib::ustring& message,  const std::vector<Glib::ustr
   //
   if (greet.size())
   {
-    string greetings(_("Special Greetings to:\n"));
+    std::string greetings(_("Special Greetings to:\n"));
     std::vector<Glib::ustring>::const_iterator i;
     for(i = greet.begin(); i != greet.end(); i++)
     {
@@ -131,8 +130,8 @@ Hello_App::init()
   install_menus_and_toolbar();
   
   // gnomehello-signals
-  signal_hide().connect( SigC::bind<Hello_App*>(SigC::slot(appset, &AppSet::on_app_hide), this) );
-  button_.signal_clicked().connect( SigC::slot(*this, &Hello_App::on_button_clicked) );
+  signal_hide().connect( sigc::bind<Hello_App*>(sigc::mem_fun(appset, &AppSet::on_app_hide), this) );
+  button_.signal_clicked().connect( sigc::mem_fun(*this, &Hello_App::on_button_clicked) );
 
   // Register an instance of myself
   appset.add_app(this);
@@ -148,13 +147,13 @@ Hello_App::install_menus_and_toolbar()
     using namespace Gnome::UI::MenuItems;
 
     // File menu
-    file_menu.push_back( New(_("New hello"), _("Creates new hello"), SigC::slot(*this, &Hello_App::on_menu_file_new)) );
+    file_menu.push_back( New(_("New hello"), _("Creates new hello"), sigc::mem_fun(*this, &Hello_App::on_menu_file_new)) );
     file_menu.push_back( Open() );
     file_menu.push_back( Save() );
     file_menu.push_back( SaveAs() );
     file_menu.push_back( Gnome::UI::Items::Separator() );
-    file_menu.push_back( Close(SigC::slot(*this, &Hello_App::on_menu_file_close)) );
-    file_menu.push_back( Exit(SigC::slot(*this, &Hello_App::on_menu_file_exit)) );
+    file_menu.push_back( Close(sigc::mem_fun(*this, &Hello_App::on_menu_file_close)) );
+    file_menu.push_back( Exit(sigc::mem_fun(*this, &Hello_App::on_menu_file_exit)) );
 
     // Edit Menu (stubs)
     edit_menu.push_back(Cut());
@@ -172,7 +171,7 @@ Hello_App::install_menus_and_toolbar()
     // Help Menu
     // this pulls in all the helps items
     help_menu.push_back(Gnome::UI::Items::Help("gnomemm_hello"));
-    help_menu.push_back(About(SigC::slot(*this, &Hello_App::on_menu_help_about)));
+    help_menu.push_back(About(sigc::mem_fun(*this, &Hello_App::on_menu_help_about)));
   }
 
   {
@@ -194,18 +193,18 @@ Hello_App::install_menus_and_toolbar()
   std::vector<Gnome::UI::Items::Info> toolbar;
   {
     using namespace Gnome::UI::Items;
-    toolbar.push_back(Item(Icon(GNOME_STOCK_PIXMAP_NEW),
+    toolbar.push_back(Item(Icon(Gtk::Stock::NEW),
                            _("New Hello"),
-                           SigC::slot(*this, &Hello_App::on_menu_file_new),
+                           sigc::mem_fun(*this, &Hello_App::on_menu_file_new),
                            _("Create a new hello")));
     toolbar.push_back(Separator());
-    toolbar.push_back(Item(Icon(GNOME_STOCK_PIXMAP_BACK),
+    toolbar.push_back(Item(Icon(Gtk::Stock::GO_BACK),
                            _("Prev"),
-                           SigC::slot(*this, &Hello_App::nothing_cb),
+                           sigc::mem_fun(*this, &Hello_App::nothing_cb),
                            _("Previous hello")));
-    toolbar.push_back(Item(Icon(GNOME_STOCK_PIXMAP_FORWARD),
+    toolbar.push_back(Item(Icon(Gtk::Stock::GO_FORWARD),
                            _("Next"),
-                           SigC::slot(*this, &Hello_App::nothing_cb),
+                           sigc::mem_fun(*this, &Hello_App::nothing_cb),
                            _("Next hello")));
     create_toolbar(toolbar);
   }
@@ -287,7 +286,7 @@ Hello_App::on_menu_help_about()
                              refLogo);
 
     about_->set_transient_for(*this);
-    about_->signal_hide().connect(SigC::slot(*this, &Hello_App::on_about_hide));
+    about_->signal_hide().connect(sigc::mem_fun(*this, &Hello_App::on_about_hide));
     about_->show();
   }
 }
